# Changelog

<!--next-version-placeholder-->

## v2.0.0 (2024-xx-xx)
### BREAKING CHANGE

* Rewrite from Python to Rust.


## v1.x.x

See [CHANGELOG.md @ robinvandernoord/uvx](https://github.com/robinvandernoord/uvx/blob/master/CHANGELOG.md)
